
# Breezyhr Connector

> Breezyhr is an end-to-end recruiting software to help you attract & hire great employees with less effort


🔗 https://breezy.hr/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profiles**](docs/push_profiles.md) |
